Descriptor class

Wallet descriptor class used to create a new wallet

Constructors

Descriptor({required String ctDescriptor})
const

Properties

ctDescriptor String
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

newConfidential({required Network network, required String mnemonic}) Future<Descriptor>
Createa new wpkh confidential descriptor based on Slip77 blinding key derivation